@@ -6,22 +6,39 @@ use Carp;
 use File::Basename;
 
 sub new {
-    my $class = shift;
-    $class =~ s#^$PREFIX##;
-    foreach my $impl (VCS->implementations) {
-        my $this_class = "$impl$class";
-        my $self = $this_class->new(@_);
-        return $self if defined $self;
-    }
-    return;
+    my $container_classtype = shift;
+    $container_classtype =~ s#^$PREFIX##;
+    my ($hostname, $impl_class, $path, $query) = VCS->parse_url(@_);
+    VCS->class_load($impl_class);
+    my $this_class = "$impl_class$container_classtype";
+    return $this_class->new(@_);
 }
 
-sub name {
+sub init {
+    my ($class, $url) = @_;
+    my ($hostname, $impl_class, $path, $query) = VCS->parse_url($url);
+    my $self = {};
+    $self->{URL} = $url;
+    $self->{PATH} = $path;
+    bless $self, $class;
+}
+
+sub url {
+    my $self = shift;
+    $self->{URL};
+}
+
+sub tags {
 }
 
 sub versions {
 }
 
+sub path {
+    my $self = shift;
+    $self->{PATH};
+}
+
 1;
 
 __END__
@@ -33,8 +50,8 @@ VCS::File - module for access to a file under version control
 =head1 SYNOPSIS
 
     use VCS;
-    my $f = VCS::File->new($file);
-    print $f->name . "\n";
+    my $f = VCS::File->new($url);
+    print $f->url . "\n";
     foreach my $v ($f->versions) {
         print "\tversion: " . $v->version . "\t" . ref($v) . "\n";
     }
@@ -51,9 +68,9 @@ Methods marked with a "*" are not yet finalised/implemented.
 
 C<$name> is a file name, absolute or relative.  Creates data as
 appropriate to convince the VCS that there is a file, and returns an
-object of class C<VCS::File>, or undef if it fails. This is a pure
-virtual method, which must be over-ridden, and cannot be called
-directly in this class (a C<die> will result).
+object of class C<VCS::File>, or throws an exception if it fails. This
+is a pure virtual method, which must be over-ridden, and cannot be called
+directly in this class (an exception ("C<die>") will result).
 
 =head2 VCS::File-E<gt>introduce($version_args) *
 
@@ -71,14 +88,27 @@ code, to call create_new in the right C<VCS::Version> subclass:
 This is a pure virtual method, which must be over-ridden, and cannot be
 called directly in this class (a C<die> will result).
 
-=head2 VCS::File-E<gt>new($file)
+=head2 VCS::File-E<gt>new($url)
 
-C<$file> is a file name, absolute or relative.  Returns an object
-of class C<VCS::File>, or undef if it fails.
+C<$url> is a file URL.  Returns an object of class C<VCS::File>, or
+throws an exception if it fails. Normally, an override of this method
+will call C<VCS::File-E<gt>init($url)> to make an object, and then add
+to it as appropriate.
 
-=head2 $file-E<gt>name
+=head2 VCS::File-E<gt>tags()
 
-Returns the C<$file> argument to C<new>.
+Returns a reference to a hash that has keys that are any tags attached
+to the file and the values are the corresponding versions which the
+tags refer to.
+
+=head2 VCS::File-E<gt>init($url)
+
+C<$url> is a file URL. Returns an object of class C<VCS::File>. This
+method calls C<VCS-E<gt>parse_url> to make sense of the URL.
+
+=head2 $file-E<gt>url
+
+Returns the C<$url> argument to C<new>.
 
 =head2 $file-E<gt>versions
 
@@ -86,6 +116,10 @@ Returns a list of objects of class C<VCS::Version>, in order of ascending
 revision number. If it is passed an extra (defined) argument, it only
 returns the last version as a C<VCS::Version>.
 
+=head2 $file-E<gt>path
+
+Returns the absolute path of the file.
+
 =head1 SEE ALSO
 
 L<VCS>.
